@@ -92,3 +92,10 @@ class DXFDigestNotAvailableForSchema1(DXFError):
     """
     def __str__(self):
         return 'Schema 1 manifest has no configuration blob. See https://github.com/docker/distribution/issues/1662#issuecomment-213101772'
+
+class DXFMountFailed(DXFError):
+    """
+    Failed to mount blob from another repository.
+    """
+    def __str__(self):
+        return 'Cross repository blob mount failed'
